@@ -232,6 +232,7 @@ def load_workspace(config_file, args):
     t = Server(
         socket_name=args.socket_name,
         socket_path=args.socket_path,
+        colors=args.colors
     )
 
     try:
@@ -301,7 +302,6 @@ def get_server_from_args(args):
 def command_freeze(args):
     """ Import teamocil config to tmuxp format. """
 
-    logger.error(args)
     session = t.findWhere({
         'session_name': args.session_name
     })
@@ -340,7 +340,7 @@ def command_freeze(args):
 
             dest = dest_prompt
 
-        dest = os.path.abspath(os.path.relpath(dest))
+        dest = os.path.abspath(os.path.relpath(os.path.expanduser(dest)))
         if prompt_yes_no('Write to %s?' % dest):
             buf = open(dest, 'w')
             buf.write(newconfig)
@@ -395,7 +395,6 @@ def command_load(args):
         else:
             logger.error('%s not found.' % configfile)
 
-
 def command_import_teamocil(args):
     """ Import teamocil config to tmuxp format. """
 
@@ -426,17 +425,17 @@ def command_import_teamocil(args):
 
             print(output)
     elif args.config:
-        configfile = os.path.abspath(os.path.relpath(args.config))
+        configfile = os.path.abspath(os.path.relpath(os.path.expanduser(args.config)))
         configparser = kaptan.Kaptan(handler='yaml')
 
         if os.path.exists(configfile):
             print(configfile)
             configparser.import_config(configfile)
+            newconfig = config.import_tmuxinator(configparser.get())
+            configparser.import_config(newconfig)
         else:
             sys.exit('File not found: %s' % configfile)
 
-        newconfig = config.import_teamocil(configparser.get())
-
         config_format = prompt_choices('Convert to', choices=[
                                        'yaml', 'json'], default='yaml')
 
@@ -467,7 +466,7 @@ def command_import_teamocil(args):
 
                 dest = dest_prompt
 
-            dest = os.path.abspath(os.path.relpath(dest))
+            dest = os.path.abspath(os.path.relpath(os.path.expanduser(dest)))
             if prompt_yes_no('Write to %s?' % dest):
                 buf = open(dest, 'w')
                 buf.write(newconfig)
@@ -512,17 +511,17 @@ def command_import_tmuxinator(args):
             print(output)
 
     if args.config:
-        configfile = os.path.abspath(os.path.relpath(args.config))
+        configfile = os.path.abspath(os.path.relpath(os.path.expanduser(args.config)))
         configparser = kaptan.Kaptan(handler='yaml')
 
         if os.path.exists(configfile):
             print(configfile)
             configparser.import_config(configfile)
+            newconfig = config.import_tmuxinator(configparser.get())
+            configparser.import_config(newconfig)
         else:
             sys.exit('File not found: %s' % configfile)
 
-        newconfig = config.import_tmuxinator(configparser.get())
-
         config_format = prompt_choices('Convert to', choices=[
                                        'yaml', 'json'], default='yaml')
 
@@ -539,7 +538,7 @@ def command_import_tmuxinator(args):
         print(
             '---------------------------------------------------------------')
         print(
-            'Configuration import does its best to convert teamocil files.\n')
+            'Configuration import does its best to convert tmuxinator files.\n')
         if prompt_yes_no(
             'The new config *WILL* require adjusting afterwards. Save config?'
         ):
@@ -553,7 +552,7 @@ def command_import_tmuxinator(args):
 
                 dest = dest_prompt
 
-            dest = os.path.abspath(os.path.relpath(dest))
+            dest = os.path.abspath(os.path.relpath(os.path.expanduser(dest)))
             if prompt_yes_no('Write to %s?' % dest):
                 buf = open(dest, 'w')
                 buf.write(newconfig)
