@@ -241,24 +241,29 @@ def import_tmuxinator(sconf):
     tmuxp_config = {}
 
     if 'project_name' in sconf:
-        tmuxp_config['session_name'] = sconf['project_name']
+        tmuxp_config['session_name'] = sconf.pop('project_name')
     elif 'name' in sconf:
-        tmuxp_config['session_name'] = sconf['name']
+        tmuxp_config['session_name'] = sconf.pop('name')
     else:
         tmuxp_config['session_name'] = None
 
+    if 'project_root' in sconf:
+        tmuxp_config['start_directory'] = sconf.pop('project_root')
+
     if 'cli_args' in sconf:
         tmuxp_config['config'] = sconf['cli_args']
 
         if '-f' in tmuxp_config['config']:
             tmuxp_config['config'] = tmuxp_config[
-                'config'].replace('-f', '').strip()
+                'config'
+            ].replace('-f', '').strip()
     elif 'tmux_options' in sconf:
         tmuxp_config['config'] = sconf['tmux_options']
 
         if '-f' in tmuxp_config['config']:
             tmuxp_config['config'] = tmuxp_config[
-                'config'].replace('-f', '').strip()
+                'config'
+            ].replace('-f', '').strip()
 
     if 'socket_name' in sconf:
         tmuxp_config['socket_name'] = sconf['socket_name']
@@ -312,10 +317,8 @@ def import_tmuxinator(sconf):
             if 'layout' in v:
                 windowdict['layout'] = v['layout']
             tmuxp_config['windows'].append(windowdict)
-
     return tmuxp_config
 
-
 def import_teamocil(sconf):
     '''Import yaml configs from `teamocil`_.
 
