@@ -127,6 +127,7 @@ class WorkspaceBuilder(object):
                 )
 
             assert(self.sconf['session_name'] == session.get('session_name'))
+            assert(len(self.sconf['session_name']) > 0)
 
         self.session = session
 
@@ -165,6 +166,7 @@ class WorkspaceBuilder(object):
             if i == int(1):  # if first window, use window 1
                 w1 = s.attached_window()
                 w1.move_window(99)
+                pass
             w = s.new_window(
                 window_name=window_name,
                 start_directory=wconf['start_directory'] if 'start_directory' in wconf else None,
@@ -246,8 +248,6 @@ def freeze(session):
                    'cd ' + p.get('pane_current_path'))
             pconf['shell_command'].append(p.get('pane_current_command'))
             wconf['panes'].append(pconf)
-            # logger.error(p)
-            # logger.error(dict(p))
 
         sconf['windows'].append(wconf)
 
